@@ -18,7 +18,6 @@ pub mod common;
 use self::core::core::hash::Hashed;
 use self::core::global;
 use self::keychain::{ExtKeychain, Keychain};
-use self::util::RwLock;
 use crate::common::*;
 use grin_core as core;
 use grin_keychain as keychain;
@@ -79,7 +78,7 @@ fn test_block_building_max_weight() {
 
 	// Fees and weights of our original txs in insert order.
 	assert_eq!(
-		txs.iter().map(|x| x.fee(header.height)).collect::<Vec<_>>(),
+		txs.iter().map(|x| x.fee()).collect::<Vec<_>>(),
 		[2_500_000, 90_000, 80_000, 30_000, 70_000, 60_000]
 	);
 	assert_eq!(
@@ -87,9 +86,7 @@ fn test_block_building_max_weight() {
 		[88, 46, 46, 25, 46, 46]
 	);
 	assert_eq!(
-		txs.iter()
-			.map(|x| x.fee_rate(header.height))
-			.collect::<Vec<_>>(),
+		txs.iter().map(|x| x.fee_rate()).collect::<Vec<_>>(),
 		[28409, 1956, 1739, 1200, 1521, 1304]
 	);
 
@@ -107,7 +104,7 @@ fn test_block_building_max_weight() {
 
 	// Fees and weights of the "mineable" txs.
 	assert_eq!(
-		txs.iter().map(|x| x.fee(header.height)).collect::<Vec<_>>(),
+		txs.iter().map(|x| x.fee()).collect::<Vec<_>>(),
 		[2_500_000, 90_000, 80_000, 70_000]
 	);
 	assert_eq!(
@@ -115,9 +112,7 @@ fn test_block_building_max_weight() {
 		[88, 46, 46, 46]
 	);
 	assert_eq!(
-		txs.iter()
-			.map(|x| x.fee_rate(header.height))
-			.collect::<Vec<_>>(),
+		txs.iter().map(|x| x.fee_rate()).collect::<Vec<_>>(),
 		[28409, 1956, 1739, 1521]
 	);
 
