@@ -187,8 +187,7 @@ fn test_the_transaction_pool() {
 		// tx4 is the "new" part of this aggregated tx that we care about
 		let agg_tx = transaction::aggregate(&[tx1.clone(), tx2.clone(), tx4]).unwrap();
 
-		let height = 12 + 1;
-		agg_tx.validate(Weighting::AsTransaction, height).unwrap();
+		agg_tx.validate(Weighting::AsTransaction).unwrap();
 
 		pool.add_to_pool(test_source(), agg_tx, false, &header)
 			.unwrap();
